@@ -6,7 +6,7 @@ use warnings;
 use File::Spec ();
 use base q(File::Spec); 
 
-our $VERSION = 0.072;
+our $VERSION = 0.073;
 
 # over-ridden class method - just a debugging wrapper
 # 
@@ -380,15 +380,15 @@ File::Spec(3) File::Copy::Link(3)
 
 =head1 AUTHOR
 
-Robin Barker, E<lt>Robin.Barker@npl.co.ukE<gt>
+Robin Barker, <RMBarker@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003, 2005, 2006, 2007 by Robin Barker
+Copyright 2003, 2005, 2006, 2007, 2011, 2014 by Robin Barker
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
 
 =cut
 
-$Id: Link.pm 221 2008-06-12 12:32:23Z rmb1 $
+$Id: Link.pm 342 2014-06-23 18:30:53Z robin $
